@@ -11,7 +11,7 @@ use vars qw($help $verbose $host);
 require DynaLoader;
 
 @ISA = qw(DynaLoader);
-$VERSION = '0.991';
+$VERSION = '0.992';
 
 @_param = qw(
 	PARAM_BOUNDARY	PARAM_CHANNEL	PARAM_COLOR	PARAM_DISPLAY	PARAM_DRAWABLE
@@ -40,7 +40,7 @@ $VERSION = '0.991';
 	SHAPEBURST_ANGULAR		SHAPEBURST_DIMPLED		SHAPEBURST_SPHERICAL
 	SHARPEN		SQUARE		STATUS_CALLING_ERROR		STATUS_EXECUTION_ERROR
 	STATUS_PASS_THROUGH		STATUS_SUCCESS	SUBTRACT_MODE	TRANS_IMAGE_FILL
-	VALUE_MODE	WHITE_IMAGE_FILL		WHITE_MASK
+	VALUE_MODE	DIVIDE_MODE	WHITE_MASK	WHITE_IMAGE_FILL
 	
 	MESSAGE_BOX	CONSOLE
 	
@@ -49,6 +49,7 @@ $VERSION = '0.991';
 	
 	TRACE_NONE	TRACE_CALL	TRACE_TYPE	TRACE_NAME	TRACE_DESC
 	TRACE_ALL
+	
 ));
 
 # procs an interface module must(!) implement somehow
@@ -142,6 +143,10 @@ sub MAGENTA_HUES	{ 6 };
 sub MESSAGE_BOX		{ 0 };
 sub CONSOLE		{ 1 };
 
+sub SHADOWS		{ 0 };
+sub MIDTONES		{ 1 };
+sub HIGHLIGHTS		{ 2 };
+
 # internal constants shared with Perl-Server
 
 sub _PS_FLAG_QUIET	{ 0000000001 };	# do not output messages
